==> types_boto3_full-1.35.74-py3-none-any.whl: types_boto3_sagemaker_geospatial/paginator.py <==
"""
Type annotations for sagemaker-geospatial service client paginators.

[Open documentation](https://youtype.github.io/types_boto3_docs/types_boto3_sagemaker_geospatial/paginators/)

Usage::

    ```python
    from boto3.session import Session

    from types_boto3_sagemaker_geospatial.client import SageMakergeospatialcapabilitiesClient
    from types_boto3_sagemaker_geospatial.paginator import (
        ListEarthObservationJobsPaginator,
        ListRasterDataCollectionsPaginator,
        ListVectorEnrichmentJobsPaginator,
    )

    session = Session()
    client: SageMakergeospatialcapabilitiesClient = session.client("sagemaker-geospatial")

    list_earth_observation_jobs_paginator: ListEarthObservationJobsPaginator = client.get_paginator("list_earth_observation_jobs")
    list_raster_data_collections_paginator: ListRasterDataCollectionsPaginator = client.get_paginator("list_raster_data_collections")
    list_vector_enrichment_jobs_paginator: ListVectorEnrichmentJobsPaginator = client.get_paginator("list_vector_enrichment_jobs")
    ```

Copyright 2024 Vlad Emelianov
"""

import sys
from typing import Generic, Iterator, TypeVar

from botocore.paginate import PageIterator, Paginator

from .type_defs import (
    ListEarthObservationJobInputListEarthObservationJobsPaginateTypeDef,
    ListEarthObservationJobOutputTypeDef,
    ListRasterDataCollectionsInputListRasterDataCollectionsPaginateTypeDef,
    ListRasterDataCollectionsOutputTypeDef,
    ListVectorEnrichmentJobInputListVectorEnrichmentJobsPaginateTypeDef,
    ListVectorEnrichmentJobOutputTypeDef,
)

if sys.version_info >= (3, 12):
    from typing import Unpack
else:
    from typing_extensions import Unpack


__all__ = (
    "ListEarthObservationJobsPaginator",
    "ListRasterDataCollectionsPaginator",
    "ListVectorEnrichmentJobsPaginator",
)


_ItemTypeDef = TypeVar("_ItemTypeDef")


class _PageIterator(PageIterator, Generic[_ItemTypeDef]):
    def __iter__(self) -> Iterator[_ItemTypeDef]:
        """
        Proxy method to specify iterator item type.
        """


class ListEarthObservationJobsPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sagemaker-geospatial/paginator/ListEarthObservationJobs.html#SageMakergeospatialcapabilities.Paginator.ListEarthObservationJobs)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_sagemaker_geospatial/paginators/#listearthobservationjobspaginator)
    """

    def paginate(
        self, **kwargs: Unpack[ListEarthObservationJobInputListEarthObservationJobsPaginateTypeDef]
    ) -> _PageIterator[ListEarthObservationJobOutputTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sagemaker-geospatial/paginator/ListEarthObservationJobs.html#SageMakergeospatialcapabilities.Paginator.ListEarthObservationJobs.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_sagemaker_geospatial/paginators/#listearthobservationjobspaginator)
        """


class ListRasterDataCollectionsPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sagemaker-geospatial/paginator/ListRasterDataCollections.html#SageMakergeospatialcapabilities.Paginator.ListRasterDataCollections)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_sagemaker_geospatial/paginators/#listrasterdatacollectionspaginator)
    """

    def paginate(
        self,
        **kwargs: Unpack[ListRasterDataCollectionsInputListRasterDataCollectionsPaginateTypeDef],
    ) -> _PageIterator[ListRasterDataCollectionsOutputTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sagemaker-geospatial/paginator/ListRasterDataCollections.html#SageMakergeospatialcapabilities.Paginator.ListRasterDataCollections.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_sagemaker_geospatial/paginators/#listrasterdatacollectionspaginator)
        """


class ListVectorEnrichmentJobsPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sagemaker-geospatial/paginator/ListVectorEnrichmentJobs.html#SageMakergeospatialcapabilities.Paginator.ListVectorEnrichmentJobs)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_sagemaker_geospatial/paginators/#listvectorenrichmentjobspaginator)
    """

    def paginate(
        self, **kwargs: Unpack[ListVectorEnrichmentJobInputListVectorEnrichmentJobsPaginateTypeDef]
    ) -> _PageIterator[ListVectorEnrichmentJobOutputTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sagemaker-geospatial/paginator/ListVectorEnrichmentJobs.html#SageMakergeospatialcapabilities.Paginator.ListVectorEnrichmentJobs.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_sagemaker_geospatial/paginators/#listvectorenrichmentjobspaginator)
        """

==> types_boto3_full-1.35.91-py3-none-any.whl: types_boto3_sagemaker_geospatial/paginator.py <==
"""
Type annotations for sagemaker-geospatial service client paginators.

[Documentation](https://youtype.github.io/types_boto3_docs/types_boto3_sagemaker_geospatial/paginators/)

Usage::

    ```python
    from boto3.session import Session

    from types_boto3_sagemaker_geospatial.client import SageMakergeospatialcapabilitiesClient
    from types_boto3_sagemaker_geospatial.paginator import (
        ListEarthObservationJobsPaginator,
        ListRasterDataCollectionsPaginator,
        ListVectorEnrichmentJobsPaginator,
    )

    session = Session()
    client: SageMakergeospatialcapabilitiesClient = session.client("sagemaker-geospatial")

    list_earth_observation_jobs_paginator: ListEarthObservationJobsPaginator = client.get_paginator("list_earth_observation_jobs")
    list_raster_data_collections_paginator: ListRasterDataCollectionsPaginator = client.get_paginator("list_raster_data_collections")
    list_vector_enrichment_jobs_paginator: ListVectorEnrichmentJobsPaginator = client.get_paginator("list_vector_enrichment_jobs")
    ```

Copyright 2025 Vlad Emelianov
"""

from __future__ import annotations

import sys
from typing import TYPE_CHECKING

from botocore.paginate import PageIterator, Paginator

from .type_defs import (
    ListEarthObservationJobInputPaginateTypeDef,
    ListEarthObservationJobOutputTypeDef,
    ListRasterDataCollectionsInputPaginateTypeDef,
    ListRasterDataCollectionsOutputTypeDef,
    ListVectorEnrichmentJobInputPaginateTypeDef,
    ListVectorEnrichmentJobOutputTypeDef,
)

if sys.version_info >= (3, 12):
    from typing import Unpack
else:
    from typing_extensions import Unpack


__all__ = (
    "ListEarthObservationJobsPaginator",
    "ListRasterDataCollectionsPaginator",
    "ListVectorEnrichmentJobsPaginator",
)


if TYPE_CHECKING:
    _ListEarthObservationJobsPaginatorBase = Paginator[ListEarthObservationJobOutputTypeDef]
else:
    _ListEarthObservationJobsPaginatorBase = Paginator  # type: ignore[assignment]


class ListEarthObservationJobsPaginator(_ListEarthObservationJobsPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sagemaker-geospatial/paginator/ListEarthObservationJobs.html#SageMakergeospatialcapabilities.Paginator.ListEarthObservationJobs)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_sagemaker_geospatial/paginators/#listearthobservationjobspaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListEarthObservationJobInputPaginateTypeDef]
    ) -> PageIterator[ListEarthObservationJobOutputTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sagemaker-geospatial/paginator/ListEarthObservationJobs.html#SageMakergeospatialcapabilities.Paginator.ListEarthObservationJobs.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_sagemaker_geospatial/paginators/#listearthobservationjobspaginator)
        """


if TYPE_CHECKING:
    _ListRasterDataCollectionsPaginatorBase = Paginator[ListRasterDataCollectionsOutputTypeDef]
else:
    _ListRasterDataCollectionsPaginatorBase = Paginator  # type: ignore[assignment]


class ListRasterDataCollectionsPaginator(_ListRasterDataCollectionsPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sagemaker-geospatial/paginator/ListRasterDataCollections.html#SageMakergeospatialcapabilities.Paginator.ListRasterDataCollections)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_sagemaker_geospatial/paginators/#listrasterdatacollectionspaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListRasterDataCollectionsInputPaginateTypeDef]
    ) -> PageIterator[ListRasterDataCollectionsOutputTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sagemaker-geospatial/paginator/ListRasterDataCollections.html#SageMakergeospatialcapabilities.Paginator.ListRasterDataCollections.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_sagemaker_geospatial/paginators/#listrasterdatacollectionspaginator)
        """


if TYPE_CHECKING:
    _ListVectorEnrichmentJobsPaginatorBase = Paginator[ListVectorEnrichmentJobOutputTypeDef]
else:
    _ListVectorEnrichmentJobsPaginatorBase = Paginator  # type: ignore[assignment]


class ListVectorEnrichmentJobsPaginator(_ListVectorEnrichmentJobsPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sagemaker-geospatial/paginator/ListVectorEnrichmentJobs.html#SageMakergeospatialcapabilities.Paginator.ListVectorEnrichmentJobs)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_sagemaker_geospatial/paginators/#listvectorenrichmentjobspaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListVectorEnrichmentJobInputPaginateTypeDef]
    ) -> PageIterator[ListVectorEnrichmentJobOutputTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sagemaker-geospatial/paginator/ListVectorEnrichmentJobs.html#SageMakergeospatialcapabilities.Paginator.ListVectorEnrichmentJobs.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_sagemaker_geospatial/paginators/#listvectorenrichmentjobspaginator)
        """
